pub struct CellRecord {
pub pid: u32,
pub token: String,
}Expand description
Immutable record established on the first Resolve for a cell.
Fields
pid: u32PID that registered this cell (SO_PEERCRED on first Resolve).
token: String32-byte hex random token set at supervisor spawn time.