pub fn load_contract(path: &Path, name: &str) -> SafeResult<AuthorityContract>Expand description
Load a single named authority contract from a manifest file.
pub fn load_contract(path: &Path, name: &str) -> SafeResult<AuthorityContract>Load a single named authority contract from a manifest file.