pub struct AuthorityTargetEvaluation {
pub decision: AuthorityTargetDecision,
pub matched_allowlist_entry: Option<String>,
}Expand description
Outcome of one contract target evaluation, including the allowlist entry that matched when the decision was positive.
Fields
decision: AuthorityTargetDecisionmatched_allowlist_entry: Option<String>Trait Implementations
Sourceimpl Clone for AuthorityTargetEvaluation
impl Clone for AuthorityTargetEvaluation
Sourcefn clone(&self) -> AuthorityTargetEvaluation
fn clone(&self) -> AuthorityTargetEvaluation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuthorityTargetEvaluation
impl Debug for AuthorityTargetEvaluation
Sourceimpl<'de> Deserialize<'de> for AuthorityTargetEvaluation
impl<'de> Deserialize<'de> for AuthorityTargetEvaluation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AuthorityTargetEvaluation
impl PartialEq for AuthorityTargetEvaluation
Sourcefn eq(&self, other: &AuthorityTargetEvaluation) -> bool
fn eq(&self, other: &AuthorityTargetEvaluation) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for AuthorityTargetEvaluation
impl StructuralPartialEq for AuthorityTargetEvaluation