pub struct EnvironmentEvidence {
pub parent_env_count: usize,
pub child_env_count: usize,
pub removed_env_count: usize,
pub safe_baseline_injected: Vec<String>,
pub secrets_injected: Vec<InjectedSecretEvidence>,
pub sensitive_env_denied: Vec<DeniedSensitiveEnvEvidence>,
}Expand description
Aggregate environment diff between parent and child processes.
parent_env_count and child_env_count are total entry counts in each
process’s env block. removed_env_count is the count of entries that
existed in the parent but were stripped from the child — this must
satisfy the invariant removed_env_count == parent_env_count - child_env_count (see RunEvidence::validation_errors).
Fields
parent_env_count: usizechild_env_count: usizeremoved_env_count: usizesafe_baseline_injected: Vec<String>secrets_injected: Vec<InjectedSecretEvidence>sensitive_env_denied: Vec<DeniedSensitiveEnvEvidence>Trait Implementations
Sourceimpl Clone for EnvironmentEvidence
impl Clone for EnvironmentEvidence
Sourcefn clone(&self) -> EnvironmentEvidence
fn clone(&self) -> EnvironmentEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EnvironmentEvidence
impl Debug for EnvironmentEvidence
Sourceimpl<'de> Deserialize<'de> for EnvironmentEvidence
impl<'de> Deserialize<'de> for EnvironmentEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EnvironmentEvidence
Sourceimpl PartialEq for EnvironmentEvidence
impl PartialEq for EnvironmentEvidence
Sourcefn eq(&self, other: &EnvironmentEvidence) -> bool
fn eq(&self, other: &EnvironmentEvidence) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for EnvironmentEvidence
impl Serialize for EnvironmentEvidence
impl StructuralPartialEq for EnvironmentEvidence