pub struct InjectedSecretEvidence {
pub name: String,
pub source: String,
pub hash: String,
pub redacted_value: String,
pub required: bool,
}Expand description
Evidence that a single secret was injected into the child process env.
Fields
name: Stringsource: Stringhash: Stringredacted_value: Stringrequired: boolTrait Implementations
Sourceimpl Clone for InjectedSecretEvidence
impl Clone for InjectedSecretEvidence
Sourcefn clone(&self) -> InjectedSecretEvidence
fn clone(&self) -> InjectedSecretEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InjectedSecretEvidence
impl Debug for InjectedSecretEvidence
Sourceimpl<'de> Deserialize<'de> for InjectedSecretEvidence
impl<'de> Deserialize<'de> for InjectedSecretEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for InjectedSecretEvidence
Sourceimpl PartialEq for InjectedSecretEvidence
impl PartialEq for InjectedSecretEvidence
Sourcefn eq(&self, other: &InjectedSecretEvidence) -> bool
fn eq(&self, other: &InjectedSecretEvidence) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for InjectedSecretEvidence
impl Serialize for InjectedSecretEvidence
impl StructuralPartialEq for InjectedSecretEvidence